@@ -5,14 +5,16 @@ use warnings;
 use Exporter        qw[import];
 use Hash::Util::Set qw[:operations];
 
-our $VERSION   = '0.06';
+our $VERSION   = '0.07';
 our @EXPORT_OK = qw[ hash_inner_join
                      hash_left_join
                      hash_right_join
                      hash_outer_join
                      hash_left_anti_join
                      hash_right_anti_join
-                     hash_full_anti_join ];
+                     hash_full_anti_join 
+                     hash_partition
+                     hash_partition_by ];
 
 our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
@@ -77,6 +79,30 @@ sub hash_full_anti_join(\%\%) {
   return wantarray ? %result : \%result;
 }
 
+sub hash_partition(\%&) {
+  my ($h, $predicate_fn) = @_;
+  my (%true, %false);
+  foreach my $k (keys %$h) {
+    if ($predicate_fn->($k, $h->{$k})) {
+      $true{$k} = $h->{$k};
+    } else {
+      $false{$k} = $h->{$k};
+    }
+  }
+  return (\%true, \%false);
+}
+
+sub hash_partition_by(\%&) {
+  my ($h, $classify_fn) = @_;
+  my %result;
+  foreach my $k (keys %$h) {
+    my $bucket = $classify_fn->($k, $h->{$k});
+    next unless defined $bucket;
+    $result{$bucket}{$k} = $h->{$k};
+  }
+  return wantarray ? %result : \%result;
+}
+
 BEGIN {
   delete @Hash::Util::Join::PP::{qw[ keys_union
                                      keys_intersection
